use clap::Parser;
use std::path::PathBuf;
use psxfileconv::{SubCommands, run_subcommand};
use tool_helper::exit_with_error;

#[derive(Parser)]
#[clap(about = "Converts files to various JabyEngine related file formats", long_about = None)]
pub struct CommandLine {
    #[clap(long="lz4", default_value_t=false)]
    compress_lz4: bool,

    #[clap(short='o')]
    output_file: Option<PathBuf>,

    #[clap(value_parser)]
    input_file: Option<PathBuf>,

    #[clap(subcommand)]
    sub_command: SubCommands,
}

fn main() {
    match CommandLine::try_parse() {
        Ok(cmd)    => {
            if let Err(error) = run_subcommand(cmd.compress_lz4, cmd.input_file, cmd.output_file, cmd.sub_command) {
                exit_with_error(error);
            }
        },
        Err(error) => println!("{}", error)
    }
}